@@ -3,9 +3,8 @@ package Log::Minimal;
 use strict;
 use warnings;
 use base qw/Exporter/;
-use Data::Dumper;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 our @EXPORT = map { ($_.'f', $_.'ff') } qw/crit warn info debug/;
 push @EXPORT, 'ddf';
 
@@ -15,7 +14,7 @@ our $PRINT = sub {
 };
 
 our $ENV_DEBUG = "LM_DEBUG";
-
+our $AUTODUMP = 0;
 our $LOG_LEVEL = 'DEBUG';
 my %log_level_map = (
     DEBUG    => 1,
@@ -91,10 +90,10 @@ sub _log {
 
     my $messages = '';
     if ( @_ == 1 && defined $_[0]) {
-        $messages = $_[0];
+        $messages = $AUTODUMP ? Log::Minimal::Dumper->new($_[0]) : $_[0];
     }
     elsif ( @_ >= 2 )  {
-        $messages = sprintf(shift, @_);
+        $messages = sprintf(shift, map { $AUTODUMP ? Log::Minimal::Dumper->new($_) : $_ } @_);
     }
 
     $messages =~ s/\x0d/\\r/g;
@@ -111,14 +110,57 @@ sub _log {
 
 sub ddf {
     my $value = shift;
-    if ( defined $value && ref($value) ) {
-        local $Data::Dumper::Terse = 1;
-        local $Data::Dumper::Indent = 0;
-        $value = Data::Dumper::Dumper($value);
+    Log::Minimal::Dumper::dumper($value);
+}
+
+1;
+
+package
+    Log::Minimal::Dumper;
+
+use strict;
+use warnings;
+use base qw/Exporter/;
+use Data::Dumper;
+use Scalar::Util qw/blessed/;
+
+use overload
+    '""' => \&stringfy,
+    '0+' => \&numeric,
+    fallback => 1;
+
+sub new {
+    my ($class, $value) = @_;
+    bless \$value, $class;
+}
+
+sub stringfy {
+    my $self = shift;
+    my $value = $$self;
+    if ( blessed($value) && (my $stringify = overload::Method( $value, '""' ) || overload::Method( $value, '0+' )) ) {
+        $value = $stringify->($value);
+    }
+    dumper($value);
+}
+
+sub numeric {
+    my $self = shift;
+    my $value = $$self;
+    if ( blessed($value) && (my $numeric = overload::Method( $value, '0+' ) || overload::Method( $value, '""' )) ) {
+        $value = $numeric->($value);
     }
     $value;
 }
 
+sub dumper {
+    my $value = shift;
+    if ( defined $value && ref($value) ) {
+        local $Data::Dumper::Terse = 1;
+        local $Data::Dumper::Indent = 0; 
+        $value = Data::Dumper::Dumper($value);
+    }
+    $value;
+}
 
 
 1;
@@ -133,15 +175,15 @@ Log::Minimal - Minimal but customizable logger.
   use Log::Minimal;
 
   critf("%s","foo"); # 2010-10-20T00:25:17 [CRITICAL] foo at example.pl line 12
-  warnf("%d %s", 1, "foo");
-  infof("foo");
+  warnf("%d %s %s", 1, "foo", $uri);
+  infof('foo');
   debugf("foo"); print if $ENV{LM_DEBUG} is true
 
   # with full stack trace
   critff("%s","foo");
   # 2010-10-20T00:25:17 [CRITICAL] foo at lib/Example.pm line 10, example.pl line 12
-  warnff("%d %s", 1, "foo");
-  infoff("foo");
+  warnff("%d %s %s", 1, "foo", $uri);
+  infoff('foo');
   debugff("foo"); print if $ENV{LM_DEBUG} is true
 
   my $serialize = ddf({ 'key' => 'value' });
@@ -163,6 +205,13 @@ Display CRITICAL messages.
 When two or more arguments are passed to the function, 
 the first argument is treated as a format of printf. 
 
+  local $Log::Minimal::AUTODUMP = 1;
+  critf({ foo => 'bar' });
+  critf("dump is %s", { foo => 'bar' });
+
+If $Log::Minimal::AUTODUMP is true, reference or object message is serialized with 
+Data::Dumper automatically.
+
 =item warnf(($message:Str|$format:Str,@list:Array));
 
 Display WARN messages.
@@ -198,7 +247,7 @@ Display DEBUG messages with stack trace, if $ENV{LM_DEBUG} is true.
 
 Utility method that serializes given value with Data::Dumper;
 
-  warnf( "dump is %s, another dump is %s", ddf($hashref), ddf($arrayref) );
+ my $serialize = ddf($hashref);
 
 
 =back
@@ -245,6 +294,21 @@ Set level to output log.
 Support levels are DEBUG,INFO,WARN,CRITICAL and NONE.
 If NONE is set, no output. Default log level is DEBUG.
 
+=item $Log::Minimal::AUTODUMP
+
+Serialize message with Data::Dumper. Default is false.
+
+  warnf("%s",{ foo => bar}); # HASH(0x100804ed0)
+
+  local $Log::Minimal::AUTODUMP = 1;
+  warnf("dump is %s", {foo=>'bar'}); #dump is {foo=>'bar'}
+
+  my $uri = URI->new("http://search.cpan.org/");
+  warnf("uri: '%s'", $uri); # uri: 'http://search.cpan.org/'
+
+If message is object and has overload methods like '""' or '0+', 
+Log::Minimal uses it instead of Data::Dumper.
+
 =back
 
 =head1 AUTHOR
